@@ -51,7 +51,8 @@ def main():
     try:
         response = build_sender(strip(args.type), config).send()
         if args.output:
-            print(response)
+            import pprint
+            pprint.pprint(response)
     except HTTPError, e:
         if args.output:
             if hasattr(e, 'fp'):
