@@ -96,7 +96,7 @@ class SystemCollector(object):
         partition_list = psutil.disk_partitions(all=True)
 
         def _sanitize(p):
-            if p is not "/":
+            if len(p) > 1:
                 return p.rstrip("/")
             return p
         path_list = map(_sanitize, path_list)
@@ -116,7 +116,7 @@ class SystemCollector(object):
                 row['path'] = part.mountpoint
                 row['percent'] = int(usage.percent)
 
-                data[part.device.replace('/dev/', '')] = row
+                data[part.device] = row
             except IndexError:
                 pass
 
